storage

package
v0.13.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 6, 2019 License: EPL-2.0 Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Storage

type Storage struct {
	sync.RWMutex
	// contains filtered or unexported fields
}

Storage stores broker execution results

func New added in v0.5.0

func New() *Storage

New creates new instance of storage

func (*Storage) AddPlugin added in v0.5.0

func (s *Storage) AddPlugin(meta *model.PluginMeta, tooling *model.ToolingConf) error

AddPlugin adds configuration of model.ChePlugin to the results of broker execution by combining model.ToolingConf and model.PluginMeta

func (*Storage) Plugins added in v0.5.0

func (s *Storage) Plugins() (*[]model.ChePlugin, error)

Plugins returns configuration of Che Plugins resolved during the broker execution. At any particular point of time configuration might be incomplete if tooling resolution failed or not completed yet

func (*Storage) SetStatus added in v0.5.0

func (s *Storage) SetStatus(status model.BrokerStatus) (ok bool, currentValue model.BrokerStatus)

SetStatus sets current status of broker execution

func (*Storage) Status added in v0.5.0

func (s *Storage) Status() model.BrokerStatus

Status returns current status of broker execution

Jump to