Documentation
¶
Index ¶
Constants ¶
const ( // StderrStream value of InstallerLogEvent.Stream if log line is from process STDERR. StderrStream = "STDERR" // StdoutStream value of InstallerLogEvent.Stream if log line is from process STDOUT. StdoutStream = "STDOUT" )
const ( StatusIdle BrokerStatus = "IDLE" StatusStarted BrokerStatus = "STARTED" StatusDone BrokerStatus = "DONE" StatusFailed BrokerStatus = "FAILED" BrokerStatusEventType = "broker/statusChanged" BrokerResultEventType = "broker/result" BrokerLogEventType = "broker/log" )
Broker statuses
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type BrokerStatus ¶
type BrokerStatus string
type CheDependencies ¶
type CheDependencies struct {
Plugins []CheDependency `json:"plugins" yaml:"plugins"`
}
type CheDependency ¶
type Container ¶
type Container struct {
Name string `json:"name" yaml:"name"`
Image string `json:"image" yaml:"image"`
Env []EnvVar `json:"env" yaml:"env"`
EditorCommands []EditorCommand `json:"editor-commands" yaml:"editor-commands"`
Volumes []Volume `json:"volumes" yaml:"volumes"`
Ports []ExposedPort `json:"ports" yaml:"ports"`
MemoryLimit string `json:"memory-limit" yaml:"memory-limit"`
}
type EditorCommand ¶
type ErrorEvent ¶
type ErrorEvent struct {
Status BrokerStatus `json:"status" yaml:"status"`
RuntimeID RuntimeID `json:"runtimeId" yaml:"runtimeId"`
Error string `json:"error" yaml:"error"`
}
type ExposedPort ¶
type ExposedPort struct {
ExposedPort int `json:"exposedPort" yaml:"exposedPort"`
}
type PluginBrokerLogEvent ¶ added in v0.2.0
type PluginBrokerLogEvent struct {
RuntimeID RuntimeID `json:"runtimeId" yaml:"runtimeId"`
// Time when this event occurred.
Time time.Time `json:"time" yaml:"text"`
// Text is written by plugin broker line of text.
Text string `json:"text" yaml:"text"`
// Stream defines whether it is STDERR or STDOUT
Stream string `json:"stream" yaml:"stream"`
}
func (*PluginBrokerLogEvent) Type ¶ added in v0.2.0
func (e *PluginBrokerLogEvent) Type() string
Type returns BrokerLogEventType.
type PluginMeta ¶
type PluginMeta struct {
ID string `json:"id" yaml:"id"`
Name string `json:"name" yaml:"name"`
Type string `json:"type" yaml:"type"`
Description string `json:"description" yaml:"description"`
Version string `json:"version" yaml:"version"`
Title string `json:"title" yaml:"title"`
Icon string `json:"icon" yaml:"icon"`
URL string `json:"url" yaml:"url"`
}
type RuntimeID ¶ added in v0.2.0
type RuntimeID struct {
// Workspace is an identifier of the workspace e.g. "workspace123456".
Workspace string `json:"workspaceId" yaml:"workspaceId"`
// Environment is a name of environment e.g. "default".
Environment string `json:"envName" yaml:"envName"`
// OwnerId is an identifier of user who is runtime owner.
OwnerId string `json:"ownerId" yaml:"ownerId"`
}
RuntimeID is an identifier of running workspace. Included to the plugin broker log events.
type StartedEvent ¶
type StartedEvent struct {
Status BrokerStatus `json:"status" yaml:"status"`
RuntimeID RuntimeID `json:"runtimeId" yaml:"runtimeId"`
}
func (*StartedEvent) Type ¶
func (e *StartedEvent) Type() string
Type returns BrokerStatusEventType.
type SuccessEvent ¶
type SuccessEvent struct {
Status BrokerStatus `json:"status" yaml:"status"`
RuntimeID RuntimeID `json:"runtimeId" yaml:"runtimeId"`
Tooling string `json:"tooling" yaml:"tooling"`
}
SuccessEvent is used to send encoded workspace tooling configuration to Che master
func (*SuccessEvent) Type ¶
func (e *SuccessEvent) Type() string
Type returns BrokerResultEventType.
type ToolingConf ¶
Click to show internal directories.
Click to hide internal directories.