storage

package
v0.3.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 5, 2018 License: EPL-2.0 Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func AddTooling

func AddTooling(tooling *model.ToolingConf) error

AddTooling adds configuration of model.ToolingConf to the results of broker execution

func Err

func Err() string

Err returns error message of broker execution if any

func SetErr

func SetErr(err string)

SetErr sets error message of broker execution

func SetStatus

func SetStatus(status model.BrokerStatus) (ok bool, currentValue model.BrokerStatus)

SetStatus sets current status of broker execution

func Status

func Status() model.BrokerStatus

Status returns current status of broker execution

func Tooling

func Tooling() (*[]model.ToolingConf, error)

Tooling returns configuration of Che plugins tooling resolved during the broker execution. At any particular point of time configuration might be incomplete if tooling resolution failed or not completed yet

Types

type Storage

type Storage struct {
	sync.RWMutex
	// contains filtered or unexported fields
}

Storage stores broker execution results

Jump to